import { useState } from "react";
import { Button } from "@/components/ui/button";
import { AnimatedBackground } from "./animated-background";
import Typewriter from 'typewriter-effect';
import { ScrollPrompt } from "./scroll-prompt";
// Import images properly for production
import doctorImage from "../assets/doctor-with-pink-ribbon.png";

export function HeroSection() {
  const [showBanner, setShowBanner] = useState(() => {
    // Check localStorage for saved preference, default to true if not found
    const savedBannerState = localStorage.getItem('showBanner');
    return savedBannerState === null ? true : savedBannerState === 'true';
  });

  const closeBanner = () => {
    setShowBanner(false);
    // Save preference to localStorage
    localStorage.setItem('showBanner', 'false');
  };
  return (
    <section className="pt-32 pb-20 px-4 md:px-8 lg:px-12 max-w-7xl mx-auto relative overflow-hidden">
      {/* Add top value proposition banner - positioned below header (70px from top) */}
      {showBanner && (
        <div 
          className="fixed top-[70px] left-1/2 transform -translate-x-1/2 py-2 px-4 bg-gradient-to-r from-pink-600 via-purple-600 to-blue-600 text-white text-center font-medium text-sm md:text-base z-40 flex items-center justify-center rounded-lg shadow-md"
          style={{ maxWidth: "90%", width: "auto" }}
        >
          <div className="flex items-center justify-between gap-3">
            <div className="flex-grow whitespace-normal">Early Detection Saves Lives: Our AI Helps Find Cancer Before Symptoms Appear</div>
            <button 
              onClick={closeBanner} 
              className="flex-shrink-0 w-6 h-6 rounded-full flex items-center justify-center text-white/80 hover:bg-white/20 focus:outline-none transition-colors"
              aria-label="Close banner"
            >
              <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2.5" strokeLinecap="round" strokeLinejoin="round" className="lucide lucide-x">
                <path d="M18 6 6 18"/><path d="m6 6 12 12"/>
              </svg>
            </button>
          </div>
        </div>
      )}

      {/* Add static background with DNA helix theme */}
      <AnimatedBackground 
        particleCount={80}
        particleColor="rgba(236, 72, 153, 0.6)" 
        secondaryColor="rgba(129, 140, 248, 0.6)"
        variant="dna"
        interactive={false}
        className="z-0"
      />
      <div className="flex flex-col lg:flex-row items-center justify-between gap-12 relative z-10">
        <div className="lg:w-1/2 space-y-6 bg-white/80 backdrop-blur-sm p-6 rounded-xl shadow-sm">
          <h1 className="text-4xl md:text-5xl lg:text-6xl font-bold leading-tight">
            <div>
              <div className="whitespace-nowrap">From Uncertainty to</div>
              <div 
                className="bg-clip-text text-transparent inline-block min-h-[1.2em] lg:min-h-[1.5em]" 
                style={{ backgroundImage: 'var(--gradient-primary)' }}
              >
                <Typewriter
                  options={{
                    strings: [
                      'Life-Saving Clarity',
                      'Early Detection',
                      'Breakthrough Science',
                      'Proactive Health',
                      'Cancer Prevention'
                    ],
                    autoStart: true,
                    loop: true,
                    delay: 50,
                    deleteSpeed: 30,
                    wrapperClassName: "inline",
                    cursorClassName: "hidden lg:inline-block opacity-50"
                  }}
                />
              </div>
            </div>
          </h1>

          <div className="max-w-xl">
            <p className="text-lg md:text-xl text-gray-600 mb-4">
              StageZero Health transforms cancer detection from reactive to proactive, detecting cancers when treatment success rates exceed 90%.
            </p>
            <p className="text-base md:text-lg text-gray-700 mb-4">
              Our personalized approach combines your health narrative with advanced AI to deliver clarity when it matters most.
            </p>
          </div>
          <div className="pt-6 flex flex-wrap gap-4">
            <a 
              href="#waitlist" 
              className="inline-block text-white px-8 py-4 rounded-md font-medium transition-all duration-200 shadow-lg hover:opacity-90"
              style={{ 
                background: 'var(--gradient-button)',
                boxShadow: '0 10px 15px -3px rgba(163, 136, 238, 0.3)'
              }}
            >
              Join the Waitlist
            </a>

            <a
              href="/login"
              className="inline-block text-gray-700 border border-purple-200 px-6 py-4 rounded-md font-medium transition-all duration-200 hover:border-purple-300"
            >
              Login
            </a>
          </div>
        </div>

        <div className="lg:w-1/2 relative">
          {/* Static image without parallax effects */}
          <div className="w-full h-[400px] md:h-[500px] rounded-xl overflow-hidden relative">
            <img 
              src={doctorImage} 
              alt="Doctor with pink cancer awareness ribbon"
              className="w-full h-full object-cover"
              width={600}
              height={500}
              loading="eager"
              fetchpriority="high"
            />
            <div className="absolute inset-0 bg-gradient-to-tr from-black/20 to-transparent z-10"></div>
          </div>

          {/* Static decorative elements with fixed positions */}
          <div 
            className="absolute -bottom-6 -left-6 w-32 h-32 rounded-lg z-20"
            style={{ background: 'var(--gradient-accent)' }}
          />

          <div 
            className="absolute -top-6 -right-6 w-24 h-24 rounded-lg z-20"
            style={{ background: 'var(--gradient-button)' }}
          />

          <div className="absolute top-1/4 right-1/4 w-16 h-16 rounded-full opacity-30 mix-blend-screen z-10">
            <div className="w-full h-full bg-pink-400 blur-lg"></div>
          </div>
        </div>
      </div>

      {/* Scroll prompt */}
      <div className="absolute bottom-0 left-0 right-0 pb-4">
        <ScrollPrompt className="text-gray-400" />
      </div>
    </section>
  );
}